@@ -2,7 +2,7 @@ package Storable::AMF0;
 use strict;
 use warnings;
 use Fcntl qw(:flock);
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 use subs qw(freeze thaw);
 use Scalar::Util qw(refaddr reftype);    # for ref_circled
 use Exporter 'import';
@@ -54,9 +54,18 @@ sub store($$) {
         croak "Bad object";
     }
     else  {
-	open my $fh, ">:raw", $file or croak "Can't open file \"$file\" for write.";
-        flock $fh, LOCK_EX if $lock;
+        my $fh;
+        if ($lock){
+            open $fh, ">>:raw", $file or croak "Can't open file \"$file\" for write.";
+            flock $fh, LOCK_EX if $lock;
+            truncate $fh, 0;
+            seek $fh,0,0;
+        }
+        else {
+            open $fh, ">:raw", $file or croak "Can't open file \"$file\" for write.";
+        }
         print $fh $$freeze if defined $$freeze;
+        close $fh;
     };
 }
 
