@@ -7,7 +7,7 @@ use Exporter 'import';
 use Carp qw(croak);
 BEGIN{
 	our $VERSION;
-	$VERSION='1.05' unless $INC{'Storable/AMF0.pm'};
+	$VERSION='1.06' unless $INC{'Storable/AMF0.pm'};
 };
 use Storable::AMF0 ();
 
@@ -56,9 +56,18 @@ sub store($$) {
         croak "Bad object";
     }
     else  {
-	open my $fh, ">:raw", $file or croak "Can't open file \"$file\" for write.";
-        flock $fh, LOCK_EX if $lock;
+        my $fh;
+        if ($lock){
+            open $fh, ">>:raw", $file or croak "Can't open file \"$file\" for write.";
+            flock $fh, LOCK_EX if $lock;
+            truncate $fh, 0;
+            seek $fh,0,0;
+        }
+        else {
+            open $fh, ">:raw", $file or croak "Can't open file \"$file\" for write.";
+        }
         print $fh $$freeze if defined $$freeze;
+        close $fh;
     };
 }
 
